# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ClusterClusterCertificateArgs',
]

@pulumi.input_type
class ClusterClusterCertificateArgs:
    def __init__(__self__, *,
                 aws_hardware_certificate: Optional[pulumi.Input[str]] = None,
                 cluster_certificate: Optional[pulumi.Input[str]] = None,
                 cluster_csr: Optional[pulumi.Input[str]] = None,
                 hsm_certificate: Optional[pulumi.Input[str]] = None,
                 manufacturer_hardware_certificate: Optional[pulumi.Input[str]] = None):
        if aws_hardware_certificate is not None:
            pulumi.set(__self__, "aws_hardware_certificate", aws_hardware_certificate)
        if cluster_certificate is not None:
            pulumi.set(__self__, "cluster_certificate", cluster_certificate)
        if cluster_csr is not None:
            pulumi.set(__self__, "cluster_csr", cluster_csr)
        if hsm_certificate is not None:
            pulumi.set(__self__, "hsm_certificate", hsm_certificate)
        if manufacturer_hardware_certificate is not None:
            pulumi.set(__self__, "manufacturer_hardware_certificate", manufacturer_hardware_certificate)

    @property
    @pulumi.getter(name="awsHardwareCertificate")
    def aws_hardware_certificate(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "aws_hardware_certificate")

    @aws_hardware_certificate.setter
    def aws_hardware_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_hardware_certificate", value)

    @property
    @pulumi.getter(name="clusterCertificate")
    def cluster_certificate(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cluster_certificate")

    @cluster_certificate.setter
    def cluster_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_certificate", value)

    @property
    @pulumi.getter(name="clusterCsr")
    def cluster_csr(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cluster_csr")

    @cluster_csr.setter
    def cluster_csr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_csr", value)

    @property
    @pulumi.getter(name="hsmCertificate")
    def hsm_certificate(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hsm_certificate")

    @hsm_certificate.setter
    def hsm_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hsm_certificate", value)

    @property
    @pulumi.getter(name="manufacturerHardwareCertificate")
    def manufacturer_hardware_certificate(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "manufacturer_hardware_certificate")

    @manufacturer_hardware_certificate.setter
    def manufacturer_hardware_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manufacturer_hardware_certificate", value)


